============
Installation
============

Install scopus from PyPI:

.. code-block:: console

    $ pip install sosia

or directly from the GitHub repository (may be unstable):

.. code-block:: console

    $ pip install git+https://github.com/sosia-dev/sosia

To access the Scopus database using `scopus`, you need to obtain credentials.  Install and `configure scopus <https://scopus.readthedocs.io/en/latest/configuration.html>`_ before using `sosia`.
